@@ -2,7 +2,7 @@
     This file is part of kalarmcal library, which provides access to KAlarm
     calendar data. Qt5 version of KDE 4 kdelibs/kdecore/date/kdatetime.h.
 
-    Copyright (c) 2005-2011,2018 David Jarvie <djarvie@kde.org>
+    Copyright © 2005-2019 David Jarvie <djarvie@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -100,9 +100,10 @@ class KADateTimeSpecPrivate;
  * A KADateTime object can be converted to a different time specification by
  * using toUtc() or toLocalZone(). It can be converted to a specific time zone
  * by toZone(). To return the time as an elapsed time since 1 January 1970 (as
- * used by time(2)), use toTime_t(). The results of time zone conversions are
- * cached to minimize the need for recalculation. Each KADateTime object caches
- * its UTC equivalent and the last time zone conversion performed.
+ * used by time(2)), use toSecsSinceEpoch(). The results of time zone
+ * conversions are cached to minimize the need for recalculation. Each
+ * KADateTime object caches its UTC equivalent and the last time zone
+ * conversion performed.
  *
  * The date and time can be set either in the constructor, or afterwards by
  * calling setDate() or setTime(). To return the date and/or time components of
@@ -336,9 +337,9 @@ public:
          * conditions apply:
          * - both instances are type @c OffsetFromUTC and their offsets from UTC are equal.
          * - both instances are type @c TimeZone and their time zones are equal.
-	 * - one instance is type @c TimeZone, with the time zone set to the system time
-	 *   zone, and the other instance is type @c LocalZone.
-	 * - both instances are type @c LocalZone.
+         * - one instance is type @c TimeZone, with the time zone set to the system time
+         *   zone, and the other instance is type @c LocalZone.
+         * - both instances are type @c LocalZone.
          * - both instances are UTC. An instance is considered to be UTC if it is
          *   either type @c UTC, or is type @c OffsetFromUTC with a zero UTC offset.
          *
@@ -701,7 +702,7 @@ public:
      * with the date unchanged.
      *
      * @return converted time
-     * @see toOffsetFromUtc(), toLocalZone(), toZone(), toTimeSpec(), toTime_t(), QTimeZone::convert()
+     * @see toOffsetFromUtc(), toLocalZone(), toZone(), toTimeSpec(), toSecsSinceEpoch(), QTimeZone::convert()
      */
     KADateTime toUtc() const;
 
@@ -716,7 +717,7 @@ public:
      * start of the day.
      *
      * @return converted time
-     * @see toUtc(), toOffsetFromUtc(int), toLocalZone(), toZone(), toTimeSpec(), toTime_t(), QTimeZone::convert()
+     * @see toUtc(), toOffsetFromUtc(int), toLocalZone(), toZone(), toTimeSpec(), toSecsSinceEpoch(), QTimeZone::convert()
      */
     KADateTime toOffsetFromUtc() const;
 
@@ -728,7 +729,7 @@ public:
      *
      * @param utcOffset number of seconds to add to UTC to get the local time.
      * @return converted time
-     * @see toUtc(), toOffsetFromUtc(), toLocalZone(), toZone(), toTimeSpec(), toTime_t(), QTimeZone::convert()
+     * @see toUtc(), toOffsetFromUtc(), toLocalZone(), toZone(), toTimeSpec(), toSecsSinceEpoch(), QTimeZone::convert()
      */
     KADateTime toOffsetFromUtc(int utcOffset) const;
 
@@ -775,14 +776,33 @@ public:
      */
     KADateTime toTimeSpec(const KADateTime &dt) const;
 
+    /**
+     * Converts the time to a UTC time, measured in seconds since 00:00:00 UTC
+     * 1st January 1970 (as returned by time(2)).
+     *
+     * @return converted time, or @c LLONG_MIN if the date is out of range or invalid
+     * @see setSecsSinceEpoch()
+     */
+    qint64 toSecsSinceEpoch() const;
+
     /**
      * Converts the time to a UTC time, measured in seconds since 00:00:00 UTC
      * 1st January 1970 (as returned by time(2)).
      *
      * @return converted time, or @c uint(-1) if the date is out of range or invalid
      * @see setTime_t()
+     * @deprecated Use toSecsSinceEpoch()
      */
-    uint toTime_t() const;
+    KALARMCAL_DEPRECATED uint toTime_t() const;
+
+    /**
+     * Sets the time to a UTC time, specified as seconds since 00:00:00 UTC
+     * 1st January 1970 (as returned by time(2)).
+     *
+     * @param seconds number of seconds since 00:00:00 UTC 1st January 1970
+     * @see toSecsSinceEpoch()
+     */
+    void setSecsSinceEpoch(qint64 seconds);
 
     /**
      * Sets the time to a UTC time, specified as seconds since 00:00:00 UTC
@@ -790,8 +810,9 @@ public:
      *
      * @param seconds number of seconds since 00:00:00 UTC 1st January 1970
      * @see toTime_t()
+     * @deprecated Use setSecsSinceEpoch()
      */
-    void setTime_t(qint64 seconds);
+    KALARMCAL_DEPRECATED void setTime_t(qint64 seconds);
 
     /**
      * Sets the instance either to being a date and time value, or a date-only
@@ -808,7 +829,7 @@ public:
      * Sets the date part of the date/time.
      *
      * @param date new date value
-     * @see date(), setTime(), setTimeSpec(), setTime_t(), setDateOnly()
+     * @see date(), setTime(), setTimeSpec(), setSecsSinceEpoch(), setDateOnly()
      */
     void setDate(const QDate &date);
 
@@ -817,7 +838,7 @@ public:
      * is changed to being a date and time value.
      *
      * @param time new time value
-     * @see time(), setDate(), setTimeSpec(), setTime_t()
+     * @see time(), setDate(), setTimeSpec(), setSecsSinceEpoch()
      */
     void setTime(const QTime &time);
 
@@ -1153,7 +1174,7 @@ public:
      * @return KADateTime value, or an invalid KADateTime if either parameter is invalid
      * @see setFromStringDefault(), toString(), QString::fromString()
      */
-    static KADateTime fromString(const QString &string, TimeFormat format = ISODate, bool *negZero = 0);
+    static KADateTime fromString(const QString &string, TimeFormat format = ISODate, bool *negZero = nullptr);
 
     /**
      * Returns the KADateTime represented by @p string, using the @p format
@@ -1288,7 +1309,7 @@ public:
      * @see setFromStringDefault(), toString()
      */
     static KADateTime fromString(const QString &string, const QString &format,
-                                const QList<QTimeZone>* zones = 0, bool offsetIfAmbiguous = true);
+                                const QList<QTimeZone>* zones = nullptr, bool offsetIfAmbiguous = true);
 
     /**
      * Sets the default time specification for use by fromString() when no time
